@@ -24,17 +24,16 @@
 #' x = xmin:100
 #' 
 #' plot(x, dpldis(x, xmin, alpha), type="l")
-dpldis = function(x, xmin, alpha, log=FALSE) {
-  x = x[round(x) >= round(xmin)]
+dpldis = function(x, xmin, alpha, log = FALSE) {
   xmin = floor(xmin)
   constant = zeta(alpha)
-  if(xmin > 1) constant = constant - sum((1:(xmin-1))^(-alpha))
+  if (xmin > 1) constant = constant - sum((1:(xmin - 1)) ^ (-alpha))
   
-  if(log) {
-    pdf = -alpha*log(x) - log(constant)
+  if (log) {
+    pdf = -alpha * log(x) - log(constant)
     pdf[round(x) < round(xmin)] = -Inf
   } else {
-    pdf = x^(-alpha)/constant
+    pdf = x ^ (-alpha) / constant
     pdf[round(x) < round(xmin)] = 0
   }
   pdf
@@ -43,9 +42,11 @@ dpldis = function(x, xmin, alpha, log=FALSE) {
 
 #'@rdname dpldis
 #'@export
-#'@details The Clauset, 2009 paper provides an algorithm for generating discrete random numbers. However, if this
-#'algorithm is implemented in R, it gives terrible performance. This is because the algorithm involves "growing vectors". 
-#'Another problem is when alpha is close to 1, this can result in very large random number being generated (which means we need 
+#'@details The Clauset, 2009 paper provides an algorithm for generating discrete random numbers. 
+#'However, if this algorithm is implemented in R, it gives terrible performance. 
+#'This is because the algorithm involves "growing vectors". 
+#'Another problem is when alpha is close to 1, this can result in very large random 
+#'number being generated (which means we need 
 #'to calculate the discrete CDF for very large values). 
 #'
 #'The algorithm provided in this package generates true 
@@ -53,26 +54,28 @@ dpldis = function(x, xmin, alpha, log=FALSE) {
 #'using continuous random numbers. This switching point can altered by 
 #'changing the \code{discrete_max} argument. 
 #'
-#'In order to get a efficient power-law discrete random number generator, the algorithm needs to be implemented in C.
+#'In order to get a efficient power-law discrete random number generator, the 
+#'algorithm needs to be implemented in C.
 #'@examples
 #' plot(x, ppldis(x, xmin, alpha), type="l", main="Distribution function")
 #' dpldis(1, xmin, alpha)
-ppldis = function(q, xmin, alpha, lower.tail=TRUE) {
-  #    q = q[round(q) >= round(xmin)]
+ppldis = function(q, xmin, alpha, lower.tail = TRUE) {
   xmin = floor(xmin)
   constant = zeta(alpha)
-  if(xmin > 1) 
-    constant = constant - sum((1:(xmin-1))^(-alpha))
-  cdf = 1-(constant - sapply(q, function(i) sum((xmin:i)^(-alpha))))/constant
-  if(!lower.tail)
+  if (xmin > 1) 
+    constant = constant - sum((1:(xmin - 1)) ^ (-alpha))
+  cdf = 1 - (constant - sapply(q, function(i) sum((xmin:i) ^ (-alpha)))) / constant
+  if (!lower.tail)
     cdf = 1 - (cdf - dpldis(q, xmin, alpha))
   cdf[round(q) < round(xmin)] = 0
   cdf
 }
 
 
-#' @param n Number of observations. If \code{length(n) > 1}, the length is taken to be the number required.
-#' @param discrete_max The value when we switch from the discrete random numbers to a CTN approximation.
+#' @param n Number of observations. If \code{length(n) > 1}, the length is 
+#' taken to be the number required.
+#' @param discrete_max The value when we switch from the discrete random 
+#' numbers to a CTN approximation.
 #' @rdname dpldis
 #' @export
 #' @examples
@@ -90,32 +93,32 @@ ppldis = function(q, xmin, alpha, lower.tail=TRUE) {
 #' 
 rpldis = function(n, xmin, alpha, discrete_max = 10000) {
   ## Initialise parameters
-  if(length(n) > 1L) n = length(n)
+  if (length(n) > 1L) n = length(n)
   
   xmin = floor(xmin)
   u = runif(n)
   
   ## Work out CDF
-  if(discrete_max > 0.5) {
+  if (discrete_max > 0.5) {
     constant = zeta(alpha)
-    if(xmin > 1) constant = constant - sum((1:(xmin-1))^(-alpha))
-    cdf = c(0, 1-(constant - cumsum((xmin:discrete_max)^(-alpha)))/constant)
+    if (xmin > 1) constant = constant - sum((1:(xmin - 1)) ^ (-alpha))
+    cdf = c(0, 1 - (constant - cumsum((xmin:discrete_max) ^ (-alpha))) / constant)
     
     ## Due to numerical instability
     ## Not enough precision to exactly calculate the CDF
-    dups = duplicated(cdf, fromLast=TRUE) 
-    if(any(dups)) cdf = cdf[1:which.min(!dups)]
+    dups = duplicated(cdf, fromLast = TRUE) 
+    if (any(dups)) cdf = cdf[1:which.min(!dups)]
     
     ## Simulate using look up method 
-    rngs = as.numeric(cut(u,cdf)) + xmin - 1
+    rngs = as.numeric(cut(u, cdf)) + xmin - 1
     
     ## Fill in blanks using Clauset approximation
     is_na = is.na(rngs)
-    if(any(is_na)) rngs[is_na] = 
-      floor((xmin-0.5)*(1-u[is_na])^(-1/(alpha-1))+0.5)
+    if (any(is_na)) rngs[is_na] = 
+      floor((xmin - 0.5) * (1 - u[is_na]) ^ (-1 / (alpha - 1)) + 0.5)
   } else {
     ## Using only the approximation
-    rngs = floor((xmin-0.5)*(1-u)^(-1/(alpha-1))+0.5)
+    rngs = floor((xmin - 0.5) * (1 - u) ^ (-1 / (alpha - 1)) + 0.5)
   }
   rngs
 }
